@@ -548,6 +548,25 @@ class TestHDUListFunctions(FitsTestCase):
         with fits.open(self.temp('temp.fits'), memmap=True) as hdul:
             assert ((old_data + 1) == hdul[1].data).all()
 
+    def test_open_file_with_bad_file_padding(self):
+        """
+        Test warning when opening files with extra padding at the end.
+        See https://github.com/astropy/astropy/issues/4351
+        """
+
+        # write some arbitrary data to a FITS file
+        fits.writeto(self.temp('temp.fits'), np.arange(100))
+        # append some arbitrary number of zeros to the end
+        with open(self.temp('temp.fits'), 'ab') as fobj:
+            fobj.write(b'\x00' * 1234)
+        with pytest.warns(
+            AstropyUserWarning,
+            match='Unexpected extra padding at the end of the file.'
+        ) as w:
+            with fits.open(self.temp('temp.fits')) as fobj:
+                fobj.info()
+        assert len(w) == 1
+
     @pytest.mark.filterwarnings('ignore:Unexpected extra padding')
     def test_open_file_with_end_padding(self):
         """Regression test for https://aeon.stsci.edu/ssb/trac/pyfits/ticket/106
@@ -976,7 +995,7 @@ class TestHDUListFunctions(FitsTestCase):
 
         # Make sure that files opened by the user are not closed
         with open(filename, mode='rb') as f:
-            with pytest.raises(OSError):
+            with pytest.raises(OSError), pytest.warns(VerifyWarning):
                 fits.open(f, ignore_missing_end=False)
 
             assert not f.closed
@@ -987,7 +1006,7 @@ class TestHDUListFunctions(FitsTestCase):
 
             assert not f.closed
 
-        with pytest.raises(OSError):
+        with pytest.raises(OSError), pytest.warns(VerifyWarning):
             fits.open(filename, ignore_missing_end=False)
 
         with pytest.raises(OSError), pytest.warns(VerifyWarning):
