@@ -1,8 +1,6 @@
-from asdf.yamlutil import custom_tree_to_tagged_tree
-
+import astropy.units as u
 import astropy.coordinates.representation
 from astropy.coordinates.representation import BaseRepresentationOrDifferential
-from astropy.tests.helper import assert_quantity_allclose
 
 from astropy.io.misc.asdf.types import AstropyType
 
@@ -27,7 +25,7 @@ class RepresentationType(AstropyType):
 
         node = {}
         node['type'] = t.__name__
-        node['components'] = custom_tree_to_tagged_tree(components, ctx)
+        node['components'] = components
 
         return node
 
@@ -43,4 +41,4 @@ class RepresentationType(AstropyType):
         for comp in new.components:
             nc = getattr(new, comp)
             oc = getattr(old, comp)
-            assert_quantity_allclose(nc, oc)
+            assert u.allclose(nc, oc)
