@@ -5,7 +5,7 @@
 This package defines units used in the CDS format, both the units
 defined in `Centre de Données astronomiques de Strasbourg
 <http://cds.u-strasbg.fr/>`_ `Standards for Astronomical Catalogues 2.0
-<http://cds.u-strasbg.fr/doc/catstd-3.2.htx>`_ format and the `complete
+<http://vizier.u-strasbg.fr/vizier/doc/catstd-3.2.htx>`_ format and the `complete
 set of supported units <http://vizier.u-strasbg.fr/cgi-bin/Unit>`_.
 This format is used by VOTable up to version 1.2.
 
@@ -146,7 +146,7 @@ def _initialize_module():
                   doc="microsecond of arc", namespace=_ns)
     core.def_unit(['mas'], u.milliarcsecond,
                   doc="millisecond of arc", namespace=_ns)
-    core.def_unit(['---'], u.dimensionless_unscaled,
+    core.def_unit(['---', '-'], u.dimensionless_unscaled,
                   doc="dimensionless and unscaled", namespace=_ns)
     core.def_unit(['%'], u.percent,
                   doc="percent", namespace=_ns)
