@@ -76,6 +76,9 @@ suppressed by setting the auto_max_age configuration variable to
   conf.auto_max_age = None
 """
 
+MONTH_ABBR = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug',
+              'Sep', 'Oct', 'Nov', 'Dec']
+
 
 def download_file(*args, **kwargs):
     """
@@ -1031,9 +1034,10 @@ class LeapSeconds(QTable):
             for line in lines:
                 match = cls._re_expires.match(line)
                 if match:
-                    expires = Time.strptime(match.groups()[0], '%d %B %Y',
-                                            scale='tai', format='iso',
-                                            out_subfmt='date')
+                    day, month, year = match.groups()[0].split()
+                    month_nb = MONTH_ABBR.index(month[:3]) + 1
+                    expires = Time(f'{year}-{month_nb:02d}-{day}',
+                                   scale='tai', out_subfmt='date')
                     break
             else:
                 raise ValueError(f'did not find expiration date in {file}')
